@@ -310,13 +310,14 @@ class IntegralWindow(QtGui.QMainWindow):
             u'Look at the SymPy site: http://sympy.org/')
 
     def showAboutBox(self):
-        versionIntegral = '1.1.3'
+        versionIntegral = '1.1.4'
         siteIntegral = 'http://www.RobertoColistete.net/Integral\n'
         infoIntegral = self.tr("Calculation of integrals using ")
         infoPython = "Python v"+python_version()
         infoSymPy = "SymPy v"+__version__+" (http://sympy.org/)"
         QtGui.QMessageBox.information(self, self.tr("About Integral"),
-            'Integral v'+versionIntegral+' - LGPLv3 (C) 2011 Roberto Colistete Jr.\n'+siteIntegral+infoIntegral+infoPython+" and\n"+infoSymPy)
+            'Integral v'+versionIntegral+' - LGPLv3 (C) 2011 Roberto Colistete Jr.\n'+\
+            siteIntegral+infoIntegral+infoPython+" and\n"+infoSymPy+'\n\n* In loving memory of my wife Lorena *')
 
     def showConfigWindow(self):
         if self.isMaemo5:
@@ -823,6 +824,8 @@ class IntegralWindow(QtGui.QMainWindow):
         return str
 
     def fixUnicodeText(self, str):
+        if self.isMaemo:
+            str = str.replace(u"⎽","_")
         str = str.replace(u"ℯ","e")
         str = str.replace(u"ⅈ","i")
         return str
